@@ -3,7 +3,6 @@ Definition of the plugin.
 """
 from django.utils.translation import ugettext_lazy as _
 from fluent_contents.extensions import ContentPlugin, plugin_pool
-from fluent_contents.plugins.oembeditem.forms import OEmbedItemForm
 from fluent_contents.plugins.oembeditem.models import OEmbedItem
 import re
 
@@ -13,11 +12,10 @@ re_safe = re.compile(r'[^\w_-]')
 @plugin_pool.register
 class OEmbedPlugin(ContentPlugin):
     model = OEmbedItem
-    category = _('Online content')
+    category = _('Media')
     admin_form_template = "admin/fluent_contents/plugins/oembeditem/admin_form.html"
     render_template = "fluent_contents/plugins/oembed/default.html"
 
-    form = OEmbedItemForm
     fieldsets = (
         (None, {
             'fields': (
