@@ -12,10 +12,6 @@ class TextPlugin(ContentPlugin):
     admin_init_template = "admin/fluent_contents/plugins/text/admin_init.html"
     admin_form_template = ContentPlugin.ADMIN_TEMPLATE_WITHOUT_LABELS
 
-    class Media:
-        js = ('fluent_contents/plugins/text/text_admin.js',)
-        css = {'screen': ('fluent_contents/plugins/text/text_admin.css',)}
-
     def render(self, request, instance, **kwargs):
         # Included in a DIV, so the next item will be displayed below.
         return mark_safe('<div class="text">' + instance.text + '</div>\n')
